pub fn is_kernel_text_address(
addr: u64,
kernel_start: u64,
kernel_end: u64,
) -> boolExpand description
Check whether an address falls within the kernel text section.
Returns true if addr is in [kernel_start, kernel_end).
_etext is the exclusive upper bound of the kernel text section.