Module envvars

Module envvars 

Linux process environment variable walker.

Reads environment variables from mm_struct.env_start..env_end for each process. The environment region contains null-separated KEY=VALUE\0 strings. Requires that the memory pages are accessible through the ObjectReader’s VAS (typically the process’s own CR3).

Functions

walk_envvars
Walk environment variables for all processes in the task list.
walk_process_envvars
Walk environment variables for a single process.