Module files

Module files 

Linux open file descriptor walker.

Enumerates open file descriptors by walking task_struct.files → files_struct.fdt → fdtable.fd[] for each process in the task list. Each struct file pointer in the fd array is dereferenced to read the dentry path name and file position.

Functions

walk_files
Walk open file descriptors for all processes.
walk_process_files
Walk open file descriptors for a single process.