Module futex_forensics

Module futex_forensics 

Futex forensics for Linux memory forensics.

Walks the kernel futex_queues hash table to enumerate all pending futex wait entries. Cross-process futexes from unexpected address ranges and abnormally high waiter counts are flagged as suspicious.

Re-exports

pub use crate::heuristics::classify_futex;

Structs

FutexInfo
Information about a futex entry found in the kernel futex hash table.

Functions

walk_futex_table
Walk the kernel futex hash table and return all pending futex entries.