MagicGidFinding

Struct MagicGidFinding 

pub struct MagicGidFinding {
    pub pid: u32,
    pub comm: String,
    pub magic_gid: u32,
    pub rootkit_name: &'static str,
}
A finding produced when a process carries a known rootkit magic GID.

Fields

pid: u32

Process ID.

comm: String

Process name (task_struct.comm, max 16 chars).

magic_gid: u32

The magic GID that triggered this finding.

rootkit_name: &'static str

Name of the rootkit associated with the magic GID.