pub fn is_miner_cmdline(cmdline: &ProcessCmdline) -> boolExpand description
Returns true if this cmdline looks like a cryptominer.
Matches when the executable contains "xmrig" or the arguments contain
"stratum+" or "--pool".
pub fn is_miner_cmdline(cmdline: &ProcessCmdline) -> boolReturns true if this cmdline looks like a cryptominer.
Matches when the executable contains "xmrig" or the arguments contain
"stratum+" or "--pool".