Module thread

Module thread 

Linux thread walker.

Enumerates threads within a process by walking the thread_group linked list in task_struct. Each thread in a thread group shares the same tgid but has a unique pid (acting as its TID).

Functions

walk_threads
Walk threads for a given process (thread group leader).