Linux hidden kernel module detector.
Cross-references kernel modules found via the modules linked list
against the kernel’s kset hierarchy (sysfs). Modules present in
one view but not the other may have been hidden by a rootkit.
Functions
- check_
hidden_ modules - Cross-reference kernel modules for hidden module detection.