Detailed process information extraction (Linux ps aux equivalent).
Extracts runtime statistics from each task_struct: CPU state,
virtual/resident memory sizes, TTY, process state, nice value.
Extends basic process enumeration with data useful for DFIR triage.
Identifies zombie processes, stopped processes, and resource anomalies.
Re-exports
pub use crate::heuristics::classify_psaux;
Structs
- PsAux
Info - Detailed process information similar to
ps auxoutput.
Functions
- task_
state_ name - Map a raw Linux task state value to a human-readable name.
- walk_
psaux - Walk the Linux process list and extract detailed
ps aux-style information.